#
# spec file for package octave-forge-image
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  image
Name:           octave-forge-%{octpkg}
Version:        2.14.0
Release:        1.9
Summary:        Image Processing for Octave
License:        BSD-2-Clause AND GPL-3.0-or-later AND MIT
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/index.html
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel >= 4.2.0
Requires:       octave-cli >= 4.2.0

%description
Functions for processing images. The package also provides functions
for feature extraction, image statistics, spatial and geometric
transformations, morphological operations, linear filtering, and much more.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.14.0:
  * The following functions are new: affine, affine2d, affine3d,
    imapplymatrix, imfuse, imshowpair.
  * New features "anti-aliasing" and "custum kernel" were added to
    imresize.  New method "box" was also added.
  * Inaccuracies in imresize bilinear interpolation and in bicubic
    interpolation were fixed, making imresize much more compatible
    with Matlab.
  * The function grayslice returns different results on input
    images of class int16.
  * Other functions that have been changed for smaller bugfixes,
    increased Matlab compatibility, or performance: psf2otf,
    imtransform.
* Sun Feb  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.12.0:
  * The following functions are new:
    imref2d               integralImage         integralImage3
    imref3d
  * Improved the cubic interpolation method in imremap.  This should
    also cause improved results in the functions imperspectivewarp,
    imresize, and imrotate when using the cubic or bicubic methods.
  * The function labelmatrix was changed for compatibility with the
    upcoming Octave version 6.
  * The function bwmorph now supports the "endpoints" operation.
  * The function nonmax_supress was renamed nonmax_suppress to fix its
    incorrect spelling.  The incorrectly named function is kept for
    backwards compatibility.
  * The functions imremap, imperspectivewrap, and imrotate no longer
    return the `valid' output argument.
  * The imgradientxy function will now recognize the methods "central"
    and "intermediate" for Matlab compatibility.  Their previous names
    "centraldifference" and "intermediatedifference" continue to work
    for backwards compatibility.
  * The stdfilt function will again handle all images of non floating
    type (a regression introduced in the version 2.10.0).
* Mon Jan 14 2019 hiwatari.seiji@gmail.com
- Update to version 2.10.0:
  * The following functions are new: axes2pix, colorangle, houghpeaks
    bwpack, deconvwnr, otsuthresh, bwunpack, houghlines
  * The functions entropyfilt, rangefilt, and stdfilt were completely
    incorrect and have now been fixed.
  * In function regionprops, "Perimeter" was changed to be compatible
    with Matlab, and "PerimterOld" was added.
  * In function regionprops, properties "ConvexHull", "ConvexImage",
    "ConvexArea", and "Solidity" were added.
  * In function bwfill, the parameter connectivity was changed to be
    Matlab compatible.
  * grayslice now expects argument V to be a vector with the actual
    values used to perform threshold.
  * The function operation "thin" in bwmorph was changed to be Matlab
    compatible.
  * imcast now also converts images to logical type.
  * wiener2 is now able to handle images with arbitrary number of
    dimensions.
  * Other functions that have been changed for smaller bugfixes,
    increased Matlab compatibility, or performance: bwdist, entropy
    hough_line, bwmorph, graythresh
  Read /usr/share/octave/packages/image-2.10.0/packinfo/NEWS for
  more details
* Wed Nov 21 2018 badshah400@gmail.com
- Update to version 2.8.1:
  * Fix imcrop for non-square images, a regression introduced in
    version 2.8.0.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 2.8.0:
  * The following functions are new: hough, imhmax, ntsc2rgb,
    imextendedmax, imhmin, rgb2ntsc, imextendedmin, imimposemin,
    viscircles, imfindcircles, imsharpen, wiener2.
  * Octave version 4.0 is no longer supported.  This makes Octave
    version 4.2.0 the minimum requirement.
  * The functions ntsc2rgb and rgb2ntsc have been removed in Octave
    core version 4.4 and are now part of the image package.  In a
    similar manner, rgb2gray, which has always been part of the image
    package, is part of Octave core version 4.4.  The versions in
    the image package will only be installed if they are missing
    from Octave to avoid shadowing the core functions.
  * imcrop will now adjust the region to crop to the image
    boundaries when the region to crop goes beyond the image
    boundaries.
  * ycbcr2rgb, rgb2ycbcr, and rgb2gray will return an image of
    class single if the input was class single (they were previously
    returning a double for such cases).
  * The function imdither has been removed.  This function hadn't
    work since Octave version 3.8.0 and would need to be
    rewritten.  The function dither from Octave core should be
    used instead but hasn't been implemented yet.  Instead of
    rewriting imdither, the missing dither function should be
    written.  See bug #41768.
  * graythresh will now clip values outside the [0 1] range in
    images of floating point class.  A side effect of this is that
    it will no longer distinguish between an image of floating
    point class that has only one one row or column, and an
    histogram.  Breaks backwards compatibility if you were
    previously relying on something like 'graythresh (img(:),
    ...)' and img is of class single or double.
  * Fix regionprops Perimeter when using a labelled image or a
    bwconncomp structure, from connectivity different from 8.
  * The functions ycbcr2rgb and rgb2ycbcr now support conversion
    according to the BT.2020 standard.
  * Other functions that have been changed for smaller bugfixes,
    increased Matlab compatibility, or performance: bwperim,
    imlincomb, imrotate, entropy, imreconstruct, normxcorr2,
    graythresh, imregionalmax, phantom, imhist, imregionalmin,
    rgb2gray.
- Update (Build)Requires: octave >= 4.2.0 now required.
* Thu Nov 24 2016 dmitry_r@opensuse.org
- Update to version 2.6.1
  * New functions.
  * Better MATLAB compatibility.
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 2.4.1
  * Bugfix release
- Drop ovsolete workaround_gcc_65843.patch
* Sat Jun 20 2015 dmitry_r@opensuse.org
- Fix build with GCC5
  * workaround_gcc_65843.patch
* Wed Apr  8 2015 dmitry_r@opensuse.org
- Update to version 2.4.0
  * The following functions are new:
    bwareafilt            imcast                imregionalmin
    bwpropfilt            imclearborder         otf2psf
    edgetaper             immse                 psf2otf
    fftconvn              imreconstruct         psnr
    imattributes          imregionalmax         subimage
  * The implementation of normxcorr2 has been changed. The new method is
    Matlab compatible and will return values in the range [-1 1].
  * The image package is no longer dependent on the signal package.
  * The disk shaped filter of fspecial has been changed for Matlab
    compatibility. The elements on the border of the disk are now
    weighted by how much of them is covered by the disk. Note that
    this change is backwards incompatible.
  * The following functions will display the output image as a figure
    instead of printing to the command line, when there are no output
    arguments:
    grayslice             im2bw
  * For better compatibility with Matlab, the imrotate, imremap, and
    imperspectivewarp functions now use 0 instead of NA for the default
    extrapolation value.
  * The regionprops function now supports the "Eccentricity",
    "MajorAxisLength", "MinorAxisLength", "EquivDiameter" and "Extrema"
    properties.  The "Orientation" property has also been rewritten for
    Matlab compatibility and may yield different results than previous
    versions.
  * The conndef function has new function signatures so that it covers all
    common ways of defining an connectivity array.
  * Creating disk shaped strel objects must now specify the N argument for
    number of periodic lines used to approximate a disk.  The value used
    must be zero to obtain the same results as previous releases of the
    image package.  No other value is at the moment valid, and this is to
    prevent future backwards incompatibility since Matlab default is 4.
    Replace any `strel ("disk", radius)' with `strel ("disk", radius, 0)'
  * The following functions have been completely rewritten and will perform
    a lot of faster.
    bwconncomp            bwlabeln
  Which indirectly will also cause the following to perform faster:
    bwareaopen             bwpropfilt            regionprops
  * Deprecated functions.
    The following functions were deprecated in image 2.2.0 and have been
    removed from image 2.4.0.
    bwborder              iptchecknargin        readexif
    impad                 iptcheckstrs
    imrotate_Fourier      uintlut
  * Other functions that have been changed for smaller bugfixes, increased
    Matlab compatibility, or performance:
    grayslice             im2single             imsmooth
    im2double             im2uint8              label2rgb
    im2int16              im2uint16
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.2.2
